@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '1.200000';
+our $VERSION = '1.300000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -79,6 +79,14 @@ C<$options> is an optional hash respecting the following keys:
 
 Causes the connection to RabbitMQ to be torn down.
 
+=head2 get_server_properties()
+
+Get a hashref of server properties (these may vary, you should C<Data::Dumper> to inspect). They will be provided by the RabbitMQ server to which you are connected.
+
+=head2 get_client_properties()
+
+Get a hashref of server properties (these may vary, you should C<Data::Dumper> to inspect).
+
 =head2 is_connected()
 
 Returns true if a valid socket connection appears to exist, false otherwise.
@@ -462,15 +470,25 @@ calls are made.
 
 =head1 AUTHORS
 
-jesus - Theo Schlossnagle E<lt>jesus@omniti.comE<gt>
+Theo Schlossnagle E<lt>jesus@omniti.comE<gt>
 
-n0body - Mark Ellis E<lt>markellis@cpan.orgE<gt>
+Mark Ellis E<lt>markellis@cpan.orgE<gt>
 
-manchicken - Michael Stemle, Jr. E<lt>themanchicken@gmail.comE<gt>
+Michael Stemle, Jr. E<lt>themanchicken@gmail.comE<gt>
 
-autarch - Dave Rolsky E<lt>autarch@urth.orgE<gt>
+Dave Rolsky E<lt>autarch@urth.orgE<gt>
 
-eserte - Slaven Rezić
+Slaven Rezić
+
+Armand Leclercq
+
+Daniel W Burke
+
+Dávid Kovács
+
+Alexey Sheynuk
+
+Karen Etheridge E<lt>ether@cpan.orgE<gt>,
 
 =head1 LICENSE
 
